pub struct ImageDimensions {
pub width: Box<IntegerWithUnits>,
pub height: Box<IntegerWithUnits>,
}Expand description
ImageDimensions : The dimensions extending from the top left corner of the cropped image, or the top left corner of the original image if there is no cropping. Only pixels is allowed as the units value for ImageDimensions.
Fields
width: Box<IntegerWithUnits>height: Box<IntegerWithUnits>Implementations
sourceimpl ImageDimensions
impl ImageDimensions
sourcepub fn new(width: IntegerWithUnits, height: IntegerWithUnits) -> ImageDimensions
pub fn new(width: IntegerWithUnits, height: IntegerWithUnits) -> ImageDimensions
The dimensions extending from the top left corner of the cropped image, or the top left corner of the original image if there is no cropping. Only pixels is allowed as the units value for ImageDimensions.